==> robustreg_0.1-3.tar.gz: robustreg/man/robustRegBS.Rd <==
\name{robustRegBS}
\alias{robustRegBS}
\title{Robust Regression Function using Bisquare Psi Function}
\description{
Using iteratively reweighted least squares (IRLS), the function calculates the optimal weights to perform m-estimator or bounded influence regression.  Returns robust beta estimates and prints robust ANOVA table.}
\usage{
robustRegBS(y,X,tune=4.685,beta,m=TRUE,max.it=1000,tol=1e-10)}
\details{
M-estimates of beta should be used when evaluating least squares estimates of beta and diagnostics show outliers.  Least squares estimates of beta should be used as starting points to achieve convergence.

Bounded influence estimates of beta should be used when evaluating least squares estimates of beta and diagnostics show large values of the "Hat Matrix" diagonals and outliers.}
\arguments{
\item{y}{A vector of dependent variables}
\item{X}{A data frame or matrix of independent variables/regressors}
\item{tune}{Tuning Constant.  Default value of 4.685 is 95\% asymptotically efficient against outliers}
\item{beta}{Starting estimates of beta for algorithm}
\item{m}{If \code{TRUE}, calculates m estimates of beta.  If \code{FALSE}, calculates bounded influence estimates of beta}
\item{max.it}{Maximum number of iterations to achieve convergence in IRLS algorithm}
\item{tol}{Tolerance level in determining convergence}
}
                                                                                                                                              \author{Ian M. Johnson \email{ian@alpha-analysis.com}}
\note{\url{http://www.alpha-analysis.com/robustreg.html}}
\references{Tukey,

Birch, Robust F-Test, 1983}
\seealso{robustRegH()}
\examples{
data(stackloss)
X<-data.frame(stackloss$Air.Flow,stackloss$Water.Temp)
y<-stackloss$stack.loss

#calculate least squares estimates for starting point
m1<-lm(stack.loss~Air.Flow+Water.Temp,data=stackloss)$coefficients

robustRegBS(y,X,beta=m1)

#If X matrix contained large values of H matrix (high influence points)
robustRegBS(y,X,beta=m1,m=FALSE)
}
\keyword{regression}

==> robustreg_0.1-5.tar.gz: robustreg/man/robustRegBS.Rd <==
\name{robustRegBS}
\alias{robustRegBS}
\title{Robust Regression Function using Bisquare Psi Function}
\description{
Using iteratively reweighted least squares (IRLS), the function calculates the optimal weights to perform m-estimator or bounded influence regression.  Returns robust beta estimates and prints robust ANOVA table.}
\usage{
robustRegBS(formula,data,tune=4.685,m=TRUE,max.it=1000,tol=1e-10)}
\details{
M-estimates of beta should be used when evaluating least squares estimates of beta and diagnostics show outliers.  Least squares estimates of beta should be used as starting points to achieve convergence.

Bounded influence estimates of beta should be used when evaluating least squares estimates of beta and diagnostics show large values of the "Hat Matrix" diagonals and outliers.}
\arguments{
\item{formula}{Model}
\item{data}{A data frame or matrix of data}
\item{tune}{Tuning Constant.  Default value of 4.685 is 95\% asymptotically efficient against outliers}
\item{m}{If \code{TRUE}, calculates m estimates of beta.  If \code{FALSE}, calculates bounded influence estimates of beta}
\item{max.it}{Maximum number of iterations to achieve convergence in IRLS algorithm}
\item{tol}{Tolerance level in determining convergence}
}
                                                                                                                                              \author{Ian M. Johnson \email{ian@alpha-analysis.com}}
\note{Original package written in 2006}
\references{Tukey,

Birch, Robust F-Test, 1983}
\seealso{robustRegH()}
\examples{
data(stackloss)
robustRegBS(stack.loss~Air.Flow+Water.Temp,data=stackloss)

#If X matrix contained large values of H matrix (high influence points)
robustRegBS(stack.loss~Air.Flow+Water.Temp,data=stackloss,m=FALSE)
}
\keyword{regression}
